/******************************************************************************************/
/*                                                                                        */
/* This SPSS program will extract the United States Sentencing Commission's               */
/* Methamphetamine Trafficking Offenses report file and create a SPSS dataset.            */
/*                                                                                        */
/* Prior to running the program you must update the DAT file location in the              */
/* FILE HANDLE DATA / NAME line to correspond to the location of the file on your         */
/* computer.                                                                              */
/*                                                                                        */
/* You must also update the file output location in the SAVE OUTFILE statement at the     */
/* end of the program to correspond to the folder you want the output file to be located. */
/*                                                                                        */
/******************************************************************************************/

/* The following line should contain the complete path and name of your raw data file */
FILENAME datafile '.\ussc_meth_report_2024_public.dat' ;

/* The following line should contain the directory in which you wish your SAS file to be stored */
libname library '.' ;

/* The following line contains the name (without the extension) for your SAS dataset */
%LET dataset = ussc_meth_report_2024_public ;

DATA library.&dataset ;
INFILE datafile LRECL=376;
INPUT
   SENSPCAP  1-8            USSCIDN  9-15            COMBDRG2  16-19       
   XCRHISSR  20-23          DRUGTYP1  24-28          GLMIN  29-44          
   FY  45-48                METHDUM  49-51           ACCAP  52-55          
   ACCTRESP  56-59          AGE  60-63               CAROFFAP  64-67       
   CIRCDIST  68-71          MONCIRC  72-75           MONRACE  76-79        
   MONSEX  80-83            NEWCIT  84-87            NEWRACE  88-91        
   SENTRNGE  92-95          TOTCHPTS  96-99          WEAPON  100-103       
   DRUGMIN  104-108         METHONLY  109-111        DEPVARPIE  112-114    
   DEPVARBAR  115-117       BORDER  118-120          RELIEF  121-123       
   IMPORT  124-126          METH  127-130            METHLABEL $ 131-135   
   AGGRL  136-138           MITRL  139-141           SUBJECTTO  142-144    
   TESTED  145-147          TESTTOSS  148-151        PURELOW  152-159      
   PUREHI  160-167          METHMATH  168-171        METHCHEM  172-175     
   METHEVID  176-178        METHACT  179-181         ICEWGT  182-190       
   ACTWGT  191-199          MIXWGT  200-209          FUNCSER  210-213      
   FUNCSERTEXT $ 214-242    IMPORTSTAT  243-245      IMPORTMEX  246-249    
   DTGORG  250-252          DTGORGTEXT $ 253-277     METHLAB  278-280      
   METHTRAP  281-283        METHSTASH  284-286       METHMINOR  287-289    
   METHHARM  290-292        METHDEATH  293-295       METHENVI  296-298     
   PURE80  299-301          GHOSTDOPE  302-304       FUNCGROUP  305-307    
   CRIMORG  308-310         ORGROLE  311-313         ANYLOC  314-316       
   SAMPLE  317-319          MIXTEST  320-322         TEST2  323-325        
   SEIZED  326-335          PUREMAX  336-343         PURE100  344-346      
   PURE96  347-349          ORGROLEDUM  350-352      DRUGS  353-355        
   USEDPOWDER  356-358      USEDCRACK  359-361       USEDHEROIN  362-364   
   USEDMJ  365-367          USEDMETH  368-370        USEDFENT  371-373     
   USEDOTH  374-376       ;                       

LENGTH
   USSCIDN 6                COMBDRG2 3               XCRHISSR 3            
   DRUGTYP1 4               FY 4                     METHDUM 3             
   ACCAP 3                  ACCTRESP 3               AGE 3                 
   CAROFFAP 3               CIRCDIST 3               MONCIRC 3             
   MONRACE 3                MONSEX 3                 NEWCIT 3              
   NEWRACE 3                SENTRNGE 3               TOTCHPTS 3            
   WEAPON 3                 DRUGMIN 4                METHONLY 3            
   DEPVARPIE 3              DEPVARBAR 3              BORDER 3              
   RELIEF 3                 IMPORT 3                 METH 3                
   AGGRL 3                  MITRL 3                  SUBJECTTO 3           
   TESTED 3                 TESTTOSS 4               METHMATH 4            
   METHCHEM 4               METHEVID 3               METHACT 3             
   FUNCSER 3                IMPORTSTAT 3             IMPORTMEX 4           
   DTGORG 3                 METHLAB 3                METHTRAP 3            
   METHSTASH 3              METHMINOR 3              METHHARM 3            
   METHDEATH 3              METHENVI 3               PURE80 3              
   GHOSTDOPE 3              FUNCGROUP 3              CRIMORG 3             
   ORGROLE 3                ANYLOC 3                 SAMPLE 3              
   MIXTEST 3                TEST2 3                  PURE100 3             
   PURE96 3                 ORGROLEDUM 3             DRUGS 3               
   USEDPOWDER 3             USEDCRACK 3              USEDHEROIN 3          
   USEDMJ 3                 USEDMETH 3               USEDFENT 3            
   USEDOTH 3 ;

         

RUN ;
